summaryrefslogtreecommitdiff
path: root/Zend/zend_exceptions.h
diff options
context:
space:
mode:
authorAaron Piotrowski <aaron@trowski.com>2015-07-03 09:45:03 -0500
committerAaron Piotrowski <aaron@trowski.com>2015-07-03 09:45:03 -0500
commited1b64877d82af71bc64a48bf914046640e8a270 (patch)
tree914694f44a90a8a76656e76f3fe0c89fdbd25b89 /Zend/zend_exceptions.h
parenta812a74c2e60a0ba080057067a7634e4da3f2b9b (diff)
downloadphp-git-ed1b64877d82af71bc64a48bf914046640e8a270.tar.gz
Switch position of ce in exception ce variable names
Diffstat (limited to 'Zend/zend_exceptions.h')
-rw-r--r--Zend/zend_exceptions.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/Zend/zend_exceptions.h b/Zend/zend_exceptions.h
index 268109af61..f9bf24b4c2 100644
--- a/Zend/zend_exceptions.h
+++ b/Zend/zend_exceptions.h
@@ -27,11 +27,11 @@
BEGIN_EXTERN_C()
extern ZEND_API zend_class_entry *zend_ce_throwable;
-extern ZEND_API zend_class_entry *zend_exception_ce;
-extern ZEND_API zend_class_entry *zend_error_exception_ce;
-extern ZEND_API zend_class_entry *zend_error_ce;
-extern ZEND_API zend_class_entry *zend_parse_error_ce;
-extern ZEND_API zend_class_entry *zend_type_error_ce;
+extern ZEND_API zend_class_entry *zend_ce_exception;
+extern ZEND_API zend_class_entry *zend_ce_error_exception;
+extern ZEND_API zend_class_entry *zend_ce_error;
+extern ZEND_API zend_class_entry *zend_ce_parse_error;
+extern ZEND_API zend_class_entry *zend_ce_type_error;
extern ZEND_API zend_class_entry *zend_ce_arithmetic_error;
extern ZEND_API zend_class_entry *zend_ce_division_by_zero_error;
@@ -45,15 +45,15 @@ void zend_register_default_exception(void);
ZEND_API zend_class_entry *zend_get_exception_base(zval *object);
/* Deprecated - Use zend_exception_ce directly instead */
ZEND_API zend_class_entry *zend_exception_get_default(void);
/* Deprecated - Use zend_error_exception_ce directly instead */
ZEND_API zend_class_entry *zend_get_error_exception(void);
ZEND_API void zend_register_default_classes(void);
/* exception_ce NULL, zend_exception_ce, zend_error_ce, or a derived class
* message NULL or the message of the exception */
ZEND_API zend_object *zend_throw_exception(zend_class_entry *exception_ce, const char *message, zend_long code);
ZEND_API zend_object *zend_throw_exception_ex(zend_class_entry *exception_ce, zend_long code, const char *format, ...);
@@ -45,15 +45,15 @@ void zend_register_default_exception(void);
ZEND_API zend_class_entry *zend_get_exception_base(zval *object);
-/* Deprecated - Use zend_exception_ce directly instead */
+/* Deprecated - Use zend_ce_exception directly instead */
ZEND_API zend_class_entry *zend_exception_get_default(void);
@@ -45,15 +45,15 @@ void zend_register_default_exception(void);
ZEND_API zend_class_entry *zend_exception_get_default(void);
-/* Deprecated - Use zend_error_exception_ce directly instead */
+/* Deprecated - Use zend_ce_error_exception directly instead */
ZEND_API zend_class_entry *zend_get_error_exception(void);
ZEND_API void zend_register_default_classes(void);
@@ -45,15 +45,15 @@ void zend_register_default_exception(void);
ZEND_API zend_class_entry *zend_get_error_exception(void);
ZEND_API void zend_register_default_classes(void);
-/* exception_ce NULL, zend_exception_ce, zend_error_ce, or a derived class
+/* exception_ce NULL, zend_ce_exception, zend_ce_error, or a derived class
* message NULL or the message of the exception */
ZEND_API zend_object *zend_throw_exception(zend_class_entry *exception_ce, const char *message, zend_long code);